==> shinyStorePlus_1.2.tar.gz: shinyStorePlus/NEWS.md <==
# shinyStorePlus 1.3
--------------------------------------------------------------------------
## Planned Features

- [ ] Store app views across all visitors
- [ ] Store app likes from all visitors
- [ ] Store outputs for DT and rhandsontable tables automatically
- [ ] Store specific variables
- [ ] Retrieve all stored specific variables & outputs

# shinyStorePlus 1.2
--------------------------------------------------------------------------
## Features

- [x] Store dynamically generated inputs, like inputs created from the server function of the shiny app. See examples in the GitHub project link

# shinyStorePlus 1.1
--------------------------------------------------------------------------
## Features

- [x] Compatibility for shinyWidgets package

# shinyStorePlus 0.9
--------------------------------------------------------------------------
## Features

- [x] Store some outputs automatically 
- [x] Updated examples of the package in action, see https://github.com/oobianom/aagarw30_shinyapps_to-shinyStorePlus

# shinyStorePlus 0.8
--------------------------------------------------------------------------
## Features

- [x] Convert browser link parameters into Shiny input values e.g Transfer the value of 'name' in http://link.com/?name=obianom to a Shiny input

# shinyStorePlus 0.7
--------------------------------------------------------------------------
## Features

- [x] Bug fix on clearStore

# shinyStorePlus 0.6
----------------------------------------------------------------------------
## Features

- [x] Store inputs automatically 
- [x] Retrieve all stored inputs
- [x] Clear Storage of all inputs
- [x] An example of the package in action

==> shinyStorePlus_1.3.tar.gz: shinyStorePlus/NEWS.md <==
# shinyStorePlus 1.4
--------------------------------------------------------------------------
## Planned Features

- [ ] Store outputs for DT and rhandsontable tables automatically
- [ ] Store specific variables
- [ ] Retrieve all stored specific variables & outputs

# shinyStorePlus 1.3
--------------------------------------------------------------------------
## Features

- [x] Store app views across all visitors
- [x] Store app likes from visitors
- [x] Store app followers

# shinyStorePlus 1.2
--------------------------------------------------------------------------
## Features

- [x] Store dynamically generated inputs, like inputs created from the server function of the shiny app. See examples in the GitHub project link

# shinyStorePlus 1.1
--------------------------------------------------------------------------
## Features

- [x] Compatibility for shinyWidgets package

# shinyStorePlus 0.9
--------------------------------------------------------------------------
## Features

- [x] Store some outputs automatically 
- [x] Updated examples of the package in action, see https://github.com/oobianom/aagarw30_shinyapps_to-shinyStorePlus

# shinyStorePlus 0.8
--------------------------------------------------------------------------
## Features

- [x] Convert browser link parameters into Shiny input values e.g Transfer the value of 'name' in http://link.com/?name=obianom to a Shiny input

# shinyStorePlus 0.7
--------------------------------------------------------------------------
## Features

- [x] Bug fix on clearStore

# shinyStorePlus 0.6
----------------------------------------------------------------------------
## Features

- [x] Store inputs automatically 
- [x] Retrieve all stored inputs
- [x] Clear Storage of all inputs
- [x] An example of the package in action
